<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://ecreations.net/
 * @since      1.0.0
 *
 * @package    Sponsor_Event_Calendar
 * @subpackage Sponsor_Event_Calendar/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Sponsor_Event_Calendar
 * @subpackage Sponsor_Event_Calendar/admin
 * @author     ecreations <josel@ecreations.net>
 */
class Sponsor_Event_Calendar_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	private $options_fields;

    public $plugin_title;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->set_options();
		$this->plugin_title = 'Event Sponsor Calendar';

	}

	/**
	 * @param $event_id
	 * @param $data
	 *
	 * Set sponsorship price to an event
	 */
	public function add_event_sponsor_price($event_id, $data){

		if ( empty( $data['EventPrice'] ) ) {

			delete_post_meta( $event_id, '_EventPrice' );

		}else{

			update_post_meta( $event_id, '_EventPrice', $data['EventPrice'] );
		}

		if ( empty( $data['ShowEvent'] ) ) {

			delete_post_meta( $event_id, '_ShowEvent' );

		}else{

			update_post_meta( $event_id, '_ShowEvent', $data['ShowEvent'] );
		}


	}

	/**
	 * @param $event_id
	 *
	 * Add input to the event form for set sponsorship price
	 */

	public function add_event_sponsor_price_html($event_id){

		$events_label_singular = tribe_get_event_label_singular();
		$_EventPrice = get_post_meta( $event_id, '_EventPrice',true);
		$_ShowEvent = get_post_meta( $event_id, '_ShowEvent',true);

		include plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/sponsor-event-calendar-admin-display.php';
	}
	public function add_event_sponsor_order_html($event_id){

		$event_order = get_post_meta($event_id, '_order',true);

		if(isset($event_order['order'])) {

			include plugin_dir_path(dirname(__FILE__)) . 'admin/partials/sponsor-event-calendar-admin-order.php';
		}
	}

	/**
	 * @param $product
	 * @param $item
	 * @return mixed
	 *
	 * Change the order item product is to the event id
	 */
	public function change_product_item($product, $item){
		
		if($product instanceof WC_Product_Simple_Sponsor) {

			$event_id = current(unserialize($item['event']));
			$product->id = $event_id;
		}
		return $product;
	}

	/**
	 * @param $order
	 * Show the website custom field in the order details
	 */
	public function custom_display_admin_order_meta($order){


		echo '<p><strong>'.__('Website').':</strong> ' . get_post_meta( $order->id, 'website', true ) . '</p>';

	}

	/**
	 * Add a custom product type to WooCommerce
	 */
	public function register_product_type(){

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/WC_Product_Simple_Sponsor.php';
	}

	public function add_event_sponsor_product(){

		// Key should be exactly the same as in the class
		$types[ 'simple_sponsor' ] = __( 'Event Sponsor' );

		return $types;
	}

	public function add_plugin_page()
	{
		// This page will be under "Settings"
		add_options_page(
			$this->plugin_title.' Settings',
			$this->plugin_title,
			'manage_options',
			$this->plugin_name.'-setting',
			array( $this, 'create_admin_page' )
		);
	}

	/**
	 * Plugin settings 
	 */
	public function create_admin_page()
	{
		// Set class property
		include 'partials/sponsor-event-calendar-admin-options.php';
	}
	public function print_section_info()
	{
		print $this->plugin_title.' settings below:';
	}
	public function page_init()
	{
		register_setting(
			$this->plugin_name.'_option_group', // Option group
			$this->plugin_name
		);

		add_settings_section(
			$this->plugin_name.'_setting_section_id', // ID
			$this->plugin_title, // Title
			array( $this, 'print_section_info' ), // Callback
			$this->plugin_name.'-setting-admin' // Page
		);

		foreach ( $this->options_fields as $id => $field )
		{

			$args     = array (
				'label_for' => $field['title'],
				'type'      => $field['type'],
				'desc'      => $field['description'],
				'id'      =>  $id
			);
			$callback = array ( $this, 'print_input_field' );

			add_settings_field(
				$id,
				$field['title'],
				$callback,
				$this->plugin_name.'-setting-admin',
				$this->plugin_name.'_setting_section_id',
				$args
			);
		}

	}
	
	
	public function print_input_field( array $args )
	{
		$type   = $args['type'];
		$id  = $args['id'];
		$desc   = $args['desc'];

		$data   = get_option($this->plugin_name);

		$value  = (isset($data[$id]))?$data[$id]:'' ;

		$value  = esc_attr( $value );

		if($type == 'select'){

			$params=array(
				 'post_type' => 'product',
				'post_status' => 'publish,pending',

			);
			$query = new WP_Query;
			$results = $query->query($params);

			echo "<select  name='$this->plugin_name[$id]'>";
			echo '<option value=""> Select Product </option>';

			foreach ($results as $product){
				$terms = get_the_terms($product->ID, 'product_type');
				$seleted = ($value == $product->ID)?'selected':'';

				if(isset($terms[0]) &&  $terms[0]->slug == 'simple_sponsor'){
					echo "<option value='$product->ID' $seleted>$product->post_title</option>";

				}

			}
			echo '</select>';

		}
		if($desc){
			echo "<br/><p class='description'>{$desc}</p>";

		}

	}

	public function  set_options(){

		$this->options_fields = array(

			'custome_product' => array(
				'title'		=> __( 'Produc Page', 'sponsor-event-calendar' ),
				'type'		=> 'select'
			),

		);

	}

}
