<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://ecreations.net/
 * @since      1.0.0
 *
 * @package    Sponsor_Event_Calendar
 * @subpackage Sponsor_Event_Calendar/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Sponsor_Event_Calendar
 * @subpackage Sponsor_Event_Calendar/includes
 * @author     ecreations <josel@ecreations.net>
 */
class Sponsor_Event_Calendar {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Sponsor_Event_Calendar_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		$this->plugin_name = 'sponsor-event-calendar';
		$this->version = '1.0.0';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Sponsor_Event_Calendar_Loader. Orchestrates the hooks of the plugin.
	 * - Sponsor_Event_Calendar_i18n. Defines internationalization functionality.
	 * - Sponsor_Event_Calendar_Admin. Defines all hooks for the admin area.
	 * - Sponsor_Event_Calendar_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-sponsor-event-calendar-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-sponsor-event-calendar-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-sponsor-event-calendar-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-sponsor-event-calendar-public.php';

		$this->loader = new Sponsor_Event_Calendar_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Sponsor_Event_Calendar_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Sponsor_Event_Calendar_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Sponsor_Event_Calendar_Admin( $this->get_plugin_name(), $this->get_version() );
		$this->loader->add_action( 'plugins_loaded', $plugin_admin, 'register_product_type' );
		$this->loader->add_filter( 'product_type_selector', $plugin_admin, 'add_event_sponsor_product' );
		$this->loader->add_filter( 'woocommerce_get_product_from_item', $plugin_admin, 'change_product_item',10,2 );

		$this->loader->add_action( 'tribe_events_details_table_bottom', $plugin_admin, 'add_event_sponsor_price_html' );
		$this->loader->add_action( 'tribe_events_details_table_bottom', $plugin_admin, 'add_event_sponsor_order_html' );
		$this->loader->add_action( 'tribe_events_update_meta', $plugin_admin, 'add_event_sponsor_price',10,2);
		$this->loader->add_action( 'woocommerce_admin_order_data_after_billing_address', $plugin_admin, 'custom_display_admin_order_meta',10,1);

		$this->loader->add_action( 'admin_menu', $plugin_admin, 'add_plugin_page' );
		$this->loader->add_action( 'admin_init', $plugin_admin, 'page_init' );
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Sponsor_Event_Calendar_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'tribe_events_single_event_after_the_content', $plugin_public, 'single_event_sponsor_links' );
		$this->loader->add_action( 'tribe_events_single_event_after_the_meta', $plugin_public, 'single_event_sponsor_details' );
		$this->loader->add_filter('query_vars', $plugin_public,'rc_add_query_vars');
		$this->loader->add_filter('init', $plugin_public,'rc_add_rewrite_rules');

		$this->loader->add_filter('woocommerce_before_single_product', $plugin_public,'return_custom_product', 10, 2);
		$this->loader->add_filter( 'woocommerce_product_tabs',$plugin_public, 'wcs_woo_remove_reviews_tab', 98 );
		$this->loader->add_filter( 'woocommerce_placeholder_img_src', $plugin_public,'custom_woocommerce_placeholder_img_src', 98 );
		$this->loader->add_filter( 'woocommerce_before_add_to_cart_button', $plugin_public,'add_event_field');


		$this->loader->add_filter( 'woocommerce_add_cart_item', $plugin_public, 'filter_woocommerce_add_cart_item',99,1 );
		$this->loader->add_action( 'wp_loaded', $plugin_public, 'add_to_cart_handler',0);

		$this->loader->add_action( 'woocommerce_billing_fields', $plugin_public, 'checkout_fields');
		$this->loader->add_filter( 'woocommerce_cart_item_permalink', $plugin_public, 'cart_item_permalink',10,2);
		$this->loader->add_action( 'woocommerce_get_cart_item_from_session', $plugin_public, 'get_cart_item_from_session',99,3);
		$this->loader->add_action( 'woocommerce_add_order_item_meta', $plugin_public, 'save_order_custom_meta',10,2);
		$this->loader->add_action( 'woocommerce_checkout_update_order_meta', $plugin_public, 'custom_checkout_field_update_order_meta'); 
		$this->loader->add_action( 'woocommerce_cart_item_product', $plugin_public, 'cart_item_product',10,3);
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Sponsor_Event_Calendar_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
