<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://ecreations.net/
 * @since      1.0.0
 *
 * @package    Sponsor_Event_Calendar
 * @subpackage Sponsor_Event_Calendar/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Sponsor_Event_Calendar
 * @subpackage Sponsor_Event_Calendar/public
 * @author     ecreations <josel@ecreations.net>
 */
class Sponsor_Event_Calendar_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	private $event;
	private $event_price;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * @param $session_data
	 * @param $values
	 * @param $key
	 * @return mixed
	 *
	 * Change the product info for the event info in  the cart
	 */
	public function get_cart_item_from_session($session_data, $values, $key){

	 	$event_id = $session_data['event'];

		$event = get_post($event_id);
		$price = get_post_meta($event_id, '_EventPrice',true);

		$session_data['data']->price = $price;
		$session_data['data']->post->post_title = $event->post_title;
		$session_data['data']->post->id = $event_id;

		return $session_data;
	}

	/**
	 * @param $cart_item_data
	 * @return mixed
	 *
	 * Add event id to the cart item
	 */
	 public function filter_woocommerce_add_cart_item($cart_item_data){

		 $event = $_POST['event'];
		 $cart_item_data['event'] = $event;

		 return $cart_item_data;
	 }

	/**
	 * @param $address_fields
	 * @return mixed
	 *
	 * Add website custom field to the checkout form
	 */
 	public function checkout_fields($address_fields){

		$address_fields['billing_company_web_site'] = Array
		(
			'label' => 'Company Website',
			'class' => Array('form-row-wide'),
			'autocomplete' => 'website',
        );


		return $address_fields;
	}

	/**
	 * @param $link
	 * @param $cart_item
	 * @return string
	 *
	 * Change the product link to the event link
	 */
	public function cart_item_permalink($link,$cart_item){

		return get_permalink( $cart_item['product_id'] ).$cart_item['event'];
	}

	public function custom_checkout_field_update_order_meta($order_id){


		if ( ! empty( $_POST['billing_company_web_site'] ) ) {
			update_post_meta( $order_id, 'website', sanitize_text_field( $_POST['billing_company_web_site'] ) );
		}
		$wc_order = new WC_Order( $order_id );
		$order_items = $wc_order->get_items();
		foreach( $order_items as $id => $item_meta ) {

			if(isset($item_meta['event'])) {
				$event = unserialize($item_meta['event']);
				$event_id = $event['event'];
				$event_meta = get_post_meta($event_id, '_order',true);

				$event_meta['order'][] = $order_id;

				update_post_meta( $event_id, '_order', $event_meta );

			}
		}

	}

	/**
	 * @param $item_id
	 * @param $item_meta
	 * @return bool
	 *
	 * 
	 */
	public function save_order_custom_meta( $item_id, $item_meta ) {

		if( ! isset( $item_meta['event'] ) ) {
			return false;
		}

		$product_meta = array(
			'event' => $item_meta['event']
		);

		wc_add_order_item_meta( $item_id, '_event', $product_meta );

	}

	public function cart_item_product( $cart_item_data, $cart_item, $cart_item_key){

		$event_id = $cart_item['event'];
		$event = get_post($event_id);

		$cart_item_data->id = $event_id;

		return $cart_item_data;
	}


	public function event_title(){

		return $this->event->post_title;
	}
	public function event_content(){

		return $this->event->post_content;
	}
	public function event_excerpt(){

		return $this->event->post_excerpt;
	}
	public function add_to_cart_handler() {
		// Check for event  data
		if( empty( $_REQUEST['event']) || !is_numeric( $_REQUEST['event'] ) ) {
			return;
		}
		$event = $_REQUEST['event'];
		// Grab the design's product object
		$product_id          = apply_filters( 'woocommerce_add_to_cart_product_id', absint( $_REQUEST['add-to-cart'] ) );

		// Grab quantity of design
		$product_quantity    = empty( $_REQUEST['quantity'] ) ? 1 : wc_stock_amount( $_REQUEST['quantity'] );
		$passed_validation   = apply_filters( 'woocommerce_add_to_cart_validation', true, $product_id, $product_quantity );


		$adding_to_cart      = wc_get_product( $product_id );


		if ( ! $adding_to_cart ) {
			return;
		}

		$variations = array();
		$cart_item_data['event'] = $event;
		
		if( $adding_to_cart->product_type == "simple" ) {
			$variation_id = $product_id;
		} else {
			$variation_id = $_REQUEST['variation_id'];
		}

		$cart_id   = WC()->cart->generate_cart_id( $product_id, $variation_id, $variations, $cart_item_data );

		if( $passed_validation) {

			WC()->cart->cart_contents[ $cart_id ] =  array_merge( $cart_item_data, array(
				'product_id'	=> $product_id,
				'variation_id'	=> $variation_id,
				'variation' 	=> $variations,
				'quantity' 		=> 1,
				'data'			=> $adding_to_cart
			));
			WC()->cart->calculate_totals();

			$products[$event] = $adding_to_cart;
			wc_add_to_cart_message( $products );
		} else {
			wc_add_notice( 'Error adding event to cart', 'error' );
		}

		if ( $address = apply_filters( 'woocommerce_add_to_cart_redirect', false ) ) {
			wp_safe_redirect( $address );
			exit;
		} elseif ( get_option( 'woocommerce_cart_redirect_after_add' ) === 'yes' ) {
			wp_safe_redirect( WC()->cart->get_cart_url() );
			exit;
		}

		//wp_redirect( get_permalink( $product_id ). $_REQUEST['event'] );
		wp_redirect( WC()->cart->get_cart_url());
		exit;

	}
	
	public function add_event_field()
	{
		global $product;

		echo  '<input type="hidden" name="event" value="'. $this->event_id .'" />';
	}
	public function return_custom_product(){

		global $wp_query,$post,$product;

		$this->event_id = $wp_query->query_vars['event'];
		$price = get_post_meta($this->event_id, '_EventPrice',true);

		if($product instanceof WC_Product_Simple_Sponsor && $price > 0){
			$this->event = get_post($this->event_id);

			add_filter('the_title', array($this,'event_title'));
			add_filter('the_content', array($this,'event_content'));
			add_filter('the_excerpt', array($this,'event_excerpt'));
		}else{
			wp_redirect( get_home_url());
			exit;
		}


	}
	public function custom_woocommerce_placeholder_img_src($src){

		$image = array();

		if(has_post_thumbnail($this->event_id )){
			$image = wp_get_attachment_image_src(get_post_thumbnail_id($this->event_id), 'single-post-thumbnail');
		}

		return !empty($image)? $image[0]:$src;
	}
	public function rc_add_query_vars( $vars) {
		$vars[] = "event";

		return $vars;
	}
	// Add the new rewrite rule to existings ones
	public function rc_add_rewrite_rules($rules) {

		add_rewrite_rule( '^product/([^/]*)/([0-9]+)/?','index.php?product=$matches[1]&event=$matches[2]', 'top');
		add_rewrite_rule( '^product/([^/]*)', 'index.php', 'top');

		flush_rewrite_rules();
	}

	/**
	 *  Add event/product link to the calendar single page
	 */
	public function single_event_sponsor_links(){

		global $post;
		$notices = Tribe__Notices::get();
		$price = get_post_meta($post->ID, '_EventPrice', true);

		if(!isset($notices['event-past']) && $price > 0) {


			$data = get_option($this->plugin_name);
			$product_id = (isset($data['custome_product'])) ? $data['custome_product'] : 'Event Sponsor';
			if (is_numeric($product_id)) {
				$product = get_post($product_id);
			} else {

				$product = get_page_by_title('Event Sponsor', OBJECT, 'product');
			}

			?>
			<div class="event-sponsor-link">
				<a title="Sponsoring this event" href="<?php echo get_permalink($product->ID) . $post->ID; ?>"
				   class="tribe-events-gcal tribe-events-button">Sponsors this event</a>
			</div>
			<?php
		}
	}

	/**
	 * Show sponsors on the event single page
	 */
	public function single_event_sponsor_details(){

		global $post;

		$event_order = get_post_meta($post->ID, '_order',true);
		$sponsor_list = array();

		if(isset($event_order['order'])) {

			foreach ($event_order['order'] as $order_id) {
				$order = new WC_Order($order_id);
				$website = get_post_meta( $order_id, 'website', true );
				$web = parse_url($website,PHP_URL_HOST);

				if('completed' == $order->status){

					$sponsor_list[] = array(
						'company' => $order->billing_company,
						'website' =>  ($web === null )? $website:$web,
						'url' => $this->addScheme($website),
					);
				}
			}
		}

		if($sponsor_list){

			include plugin_dir_path(dirname(__FILE__)) . 'public/partials/sponsor-event-calendar-public-display.php';
		}

	}

	/**
	 * @param $tabs
	 * @return mixed
	 *
	 * Remove reviews tab
	 */
	public function wcs_woo_remove_reviews_tab($tabs){

		unset($tabs['reviews']);
		return $tabs;
	}

	function addScheme($url, $scheme = 'http://')
	{
		return parse_url($url, PHP_URL_SCHEME) === null ?
			$scheme . $url : $url;
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

 		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/sponsor-event-calendar-public.css', array(), $this->version, 'all' );

	}
}
